#
# spec file for package sblim-cmpi-base
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           sblim-cmpi-base
Version:        1.6.4
Release:        7.16
Summary:        SBLIM Base Instrumentation
License:        EPL-1.0
Group:          System/Management
Url:            http://sblim.wiki.sourceforge.net/
Source0:        http://prdownloads.sourceforge.net/sblim/%{name}-%{version}.tar.bz2
Source1:        sblim-cmpi-base-rpmlintrc
# PATCH-FEATURE-OPENSUSE sblim-cmpi-base-%{version}-methods-enable.patch [ bnc#470670 ] mhrusecky@suse.cz -- Enables methods by default
Patch0:         sblim-cmpi-base-1.6.2-methods-enable.patch
Patch2:         sblim-cmpi-base-1.6.4-fix-bashisms.patch
Patch3:         0001-make-lib-dependencies-explicit-in-Makefile.am.patch
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  sblim-cmpi-devel
BuildRequires:  sblim-indication_helper-devel
BuildRequires:  sblim-sfcb
BuildRequires:  sblim-testsuite
Requires:       cim-schema
Requires:       cim-server
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Standards Based Linux Instrumentation Base Providers

%package devel
Summary:        SBLIM Base Instrumentation Header Development Files
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
SBLIM Base Provider Development Package

%package testsuite
Summary:        SBLIM Base Instrumentation (test suite)
Group:          System/Management
Requires:       %{name} = %{version}
Requires:       sblim-testsuite

%description testsuite
Test suite for the Standards Based Linux Instrumentation Base Providers

%prep
%setup -q -T -b 0
%patch0
%patch2 -p1
%patch3 -p1

%build
autoreconf -fi
%configure TESTSUITEDIR=%{_datadir}/sblim-testsuite --disable-static
# build without parallelism because of broken build system deps
make

%install
%if 0%{?fedora_version} || 0%{?centos_version} || 0%{?rhel_version} || 0%{?fedora} || 0%{?rhel}
make DESTDIR=%{buildroot} install
%else
make DESTDIR=%{buildroot} install docdir=%{_docdir}/%{name}
%endif
# don't delete .la's until we sort out if sfcb/openwbem/pegasus use ltdlopen()
# %{__rm} %{buildroot}%{_libdir}/{libcmpiOSBase_Common,libdmiinfo}.la
# remove unused libtool files
rm -f %{buildroot}/%{_libdir}/*.a
rm -f %{buildroot}/%{_libdir}/cmpi/*.a
rm -f $RPM_BUILD_ROOT/%{_libdir}/cmpi/*.la

# install indication samples into %docdir
install -m0644 ./test/indication/SFCB*.xml %{buildroot}/%{_docdir}/%{name}*

%pre
# definition of schema and registration files

%define SCHEMA %{_datadir}/%{name}/Linux_Base.mof %{_datadir}/%{name}/Linux_BaseIndication.mof
%define REGISTRATION %{_datadir}/%{name}/Linux_BaseIndication.registration
# If upgrading, deregister old version
if [ $1 -gt 1 ]
then
  %{_datadir}/%{name}/provider-register.sh -d \
	-r %{REGISTRATION} -m %{SCHEMA} > /dev/null ||:
fi

%post
# Register Schema and Provider - this is higly provider specific
# tog-pegasus needs some schemes registered first
if [ -x %{_bindir}/peg-loadmof.sh ]; then
	peg-loadmof.sh -n root/cimv2 %(for i in Card UnixProcess Processor OperatingSystem ComputerSystem ComputerSystemPackage RunningOS OSProcess SystemDevice ProcessIndication ElementStatisticalData; echo -n "%{_datadir}/mof/cim-current/*/CIM_$i.mof ")
	rctog-pegasus try-restart
fi
# and then following script can handle registration for various providers
%{_datadir}/%{name}/provider-register.sh \
	-r %{REGISTRATION} -m %{SCHEMA} > /dev/null ||:
/sbin/ldconfig

%preun
# Deregister only if not upgrading
if [ $1 -eq 0 ]
then
  %{_datadir}/%{name}/provider-register.sh -d \
	-r %{REGISTRATION} -m %{SCHEMA} > /dev/null ||:
fi

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%if 0%{?fedora_version} || 0%{?centos_version} || 0%{?rhel_version} || 0%{?fedora} || 0%{?rhel}
%docdir %{_datadir}/doc/%{name}-%{version}
%doc %{_datadir}/doc/%{name}-%{version}
%else
%doc %{_docdir}/%{name}
%endif
%dir %{_libdir}/cmpi/
%{_libdir}/cmpi/libcmpiOSBase*.so
%{_libdir}/libcmpiOSBase_Common.so.*
%{_libdir}/libdmiinfo.so.*
%dir %{_datadir}/%{name}/
%{_datadir}/%{name}/provider-register.sh
%{_datadir}/%{name}/Linux_Base*
#possibly needed atm, as per above comment... leaving for now
%{_libdir}/libcmpiOSBase_Common.la
%{_libdir}/libdmiinfo.la

%files devel
%defattr(-,root,root)
%dir %{_includedir}/sblim
%{_includedir}/sblim/*
%{_libdir}/libcmpiOSBase_Common.so
%{_libdir}/libdmiinfo.so

%files testsuite
%defattr(-,root,root)
%dir %{_datadir}/sblim-testsuite
%dir %{_datadir}/sblim-testsuite/cim
%dir %{_datadir}/sblim-testsuite/system
%dir %{_datadir}/sblim-testsuite/system/linux
%{_datadir}/sblim-testsuite/test-cmpi-base.sh
%{_datadir}/sblim-testsuite/cim/Linux*.cim
%{_datadir}/sblim-testsuite/system/linux/*.pl
%{_datadir}/sblim-testsuite/system/linux/*.system
%{_datadir}/sblim-testsuite/system/linux/Linux_OperatingSystem.version.sh
%{_datadir}/sblim-testsuite/system/linux/createKeyFiles.sh

%changelog
* Tue Aug 27 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Disable parallel make because of broken build system deps
* Tue May 15 2018 kkaempf@suse.com
- Fix missing dependencies in Makefile.am
  0001-make-lib-dependencies-explicit-in-Makefile.am.patch
- enable parallel make
* Fri Jul  3 2015 kkaempf@suse.com
- Fix RHEL7 build
* Tue Jun 23 2015 mvetter@suse.com
- cleanup spec file
  * running spec cleaner
  * install xml files with correct permission
  * 'make' only with one thread
  * remove sblim-cmpi-base-1.6.2-missing-fclose.patch as it is in upstream since git commit 3eb68295874453fdb1885489443105cb2ff6432d
* Sat Nov 29 2014 Led <ledest@gmail.com>
- fix bashisms in scripts
- add patches:
  * sblim-cmpi-base-1.6.4-fix-bashisms.patch
* Sun Nov  9 2014 Led <ledest@gmail.com>
- fix bashism in post script
* Tue Oct 28 2014 kkaempf@suse.com
- Update to 1.6.4
  Bugs Fixed:
  - SBLIM-2737: bugfix for sprintf() handling
* Thu Oct 23 2014 kkaempf@suse.com
- Update to 1.6.3
  Bugs Fixed:
  - SBLIM-2634: incorrect max cpu frequency
  - SBLIM-2644: wrong UserModeTime and KernelModeTime
  - SBLIM-2698: system name might have empty domainname
    (-> drop call-domainname.patch)
  - SBLIM-2737: datetime values do not adjust for DST
* Thu Oct 31 2013 kkaempf@suse.com
- fix Linux_ComputerSystem Name to include domain name
  (fall back to domainname if dnsdomainname is empty)
  Add call-domainname.patch
* Wed Aug 28 2013 kkaempf@suse.com
- install indication samples to docdir
* Fri Nov 30 2012 kkaempf@suse.com
- Update to 1.6.2
  Bugs Fixed:
  - 3275169 bash error reported in provider bootstrap scripts
  - 3306580 wrong OperatingSystem.Version prop value on RHEL6
  - 3424288 Underlinked libcmpiOSBase_ProcessorProvider.so
  - 3582069 Linux_UnixProcess command injection vulnerability
* Wed Feb  8 2012 puzel@suse.com
- fix file-packaged-twice error
* Sun Nov 27 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Tue May 24 2011 kkaempf@novell.com
- update to 1.6.1 (bnc#694324)
  Bugs Fixed:
  - 2843613 Missing fclose in sblim-cmpi-base
  - 2882514 leak in sblim-cmpi-base-1.5.9/cmpiOSBase_OperatingSystem.c
  - 2836926 _osbase_common_init unreliable
  - 2610775 ProcessorProvider crashes on exit (bnc#694324)
- fix license (Eclipse Public License)
* Mon May 23 2011 kkaempf@novell.com
- fix ProcessorProvider crash on exit
  (bnc#694324, upstream 2610775)
* Fri Sep 10 2010 kkaempf@novell.com
- fix RH/Fedora build
* Wed Oct 14 2009 mhrusecky@suse.cz
- sending current development version to SLE11 SP1 (fate#307089)
* Thu Oct  1 2009 mhrusecky@suse.cz
- update to version 1.6.0
  - migrate provider licenses to EPL
* Mon Aug 24 2009 mhrusecky@suse.cz
- Adding missing fclose (bnc#530325)
* Mon May 25 2009 mhrusecky@suse.cz
- Fixed registration in tog-pegasus
* Mon Mar  9 2009 mhrusecky@suse.cz
- Enabling methods by default (bnc#470670)
* Tue Mar  3 2009 mhrusecky@suse.cz
- update to version 1.5.9
  o Bugs
  - 2508592 add CMPIStatus to indication function return
  - 2634178 Versioned libcmpiOSBase_OperatingSystemProvider
  * Dropped sblim-cmpi-base-1.5.8-avoid-version.patch as it was
    accepted upstream
* Wed Feb 25 2009 mhrusecky@suse.cz
- avoiding version info in libcmpiOSBase_OperatingSystemProvider
* Mon Dec 15 2008 mhrusecky@suse.cz
- update to version 1.5.8
  o Bugs
  - 2384043: incorrect process count
  - 2308219: invokeMethod doesn't test parameter type
  - 1203827: update cmpi-base README.INDICATION for sfcb support
  - 2169940: Linux_Processor: reports wrong value for load
    percentage
  - 2065946: OSBase ProcessorProvider crashes on some platforms
  - 2093965: Linux_OperatingSystem fails to set some properties
  - 2093799: distro version script guesses wrong
  - 2089546: CIM_OS_DISTRO should only be intialized once
  - 1883918: OperatingSystem provider segfaults on file not found
  - 2089383: Shared library use of _init/_fini obsolete
  - 1832839: OSBase OperatingSystem provider returns wrong max
    processes
* Mon Aug 25 2008 npaxton@novell.com
- Revert back some of changes:
  remove symlink in /usr/sbin
  remove namespace and ow-loadmof patches in provider-register.sh
* Wed Jul  9 2008 npaxton@novell.com
- Fix docdir issues in spec file
* Wed Jul  9 2008 npaxton@novell.com
- Minor spec file cleanup
  - remove 'rm -rf buildroot'
  - move .la back to main pkg
* Mon Jul  7 2008 npaxton@novell.com
- Sync spec file between sle10-sp2 and stable
- Add symlink to this package's provider-register.sh from
  /usr/sbin : several other packages will use this package's
  provider-register script, and can't access script in
  fully-qualified path in /usr/share
* Fri May 30 2008 npaxton@novell.com
- change registration from loadmof to provider-register to support
  multiple cimoms, then modified provider-register.sh to use
  ow-loadmof.sh and ow-rmmof.sh for openwbem cimom
- added dependency on sblim-indication_helper-devel so will build
  indication support
* Mon Aug  6 2007 mrueckert@suse.de
- update to version 1.5.6
  o Bugs
  - 1626832 Test cases for class Linux_BaseBoard and association
    Linux_CSBaseBoard added
- additional changes from 1.5.5
  o Bugs
  - 1368636 Fixed infinite recursion with trace level 4.
  - 1395363 Fixed postinstall step location dependence.
- removed included patches:
  cmpi-base-proc-ia64.patch
  sblim-cmpi-base-processutil.patch
- fixed and ignored a few rpmlint warnings
- no longer build static libs
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 19 2006 mrueckert@suse.de
- replaced my header patch with a patch from upstream
* Sun Jan 15 2006 mrueckert@suse.de
- fixed Makefile to install all headers. some headers where missing
  but required for other modules.
* Mon Nov 14 2005 mrueckert@suse.de
- Fix CPU detecion on ia64.[#95989]
* Wed Oct 26 2005 mrueckert@suse.de
- Use openwbem instead of pegasuswbem.
- Update to version 1.5.4.
* Mon Sep 26 2005 mls@suse.de
- make devel package require base package
* Mon Nov 15 2004 ro@suse.de
- fixed file list
* Wed May 19 2004 nashif@suse.de
- Fix issue with empty dnsdomainname resulting in grep errors
* Mon May 17 2004 ro@suse.de
- fix spec file
* Wed May 12 2004 nashif@suse.de
- Do not deregister providers when updating package
* Mon May 10 2004 nashif@suse.de
- #40275: consistence test for class Linux_Processor fails
  on Linux on S390
- Dereigster providers when uninstalling (#39667)
* Thu Apr 29 2004 nashif@suse.de
- Install testsuite files
* Fri Apr 16 2004 nashif@suse.de
- Update version with bugfixes from IBM
* Wed Apr 14 2004 nashif@suse.de
- Added PreReq for loadmof.sh (#38891)
* Wed Apr  7 2004 nashif@suse.de
- Update to latest version from the sblim project
- register providers in %%post
- Requires cim-server
* Mon Mar 29 2004 ro@suse.de
- add x86_64/ia64 to platform.sh that code is just looking
  at proc/cpuinfo anyway
* Tue Mar 23 2004 meissner@suse.de
- really apply fpic patch.
* Tue Mar 23 2004 meissner@suse.de
- fixed lib64 handling, added -fPIC and RPM_OPT_FLAGS.
* Tue Mar 23 2004 nashif@suse.de
- Initial Release
